;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DEFINITIONS;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals [
  
  ;set simluation time simulation-start + ticks
  simulation-time
  
  ;Investment calculation variables
  ;investment-scenario ; defined in the interface, used for construction investment and rc aggregate supply calculation (-1 = minimal, 0 = trend, 1 = maximal)
  private-investment-fraction ; fraction of privat construction investments
  commercial-investment-fraction ; fraction of commercial construction investments
  public-investment-fraction ; fraction of public construction investments
  annual-construction-investment ; annual construction investment in Mio CHF
  mean-private-investment ; mean investment of private AA
  mean-commercial-investment ; mean investment of commercial AA
  mean-public-investment ; mean investment of public AA
  ; AA construction capacity
  mean-private-AA-construction-capacity
  mean-commercial-AA-construction-capacity
  mean-public-AA-construction-capacity
  
  ;Material flow accounting variables
  ;initial-RMCM-application defined in the interface used for the experience settings initially set to 8% 
  mean-concrete-mass-per-investment ;concrete mass [t] per Mio CHF invested 252 Sdt 107 
  ;variables for measuring rmcm demand on a system level
  amount-of-current-rmcm-applied ; amount of rmcm demanded in the current year [t]
  amount-of-current-cm-applied ; amount of conventional material demanded in the current year [t]
  current-fraction-rmcm-applied ; fraction per year
  total-rmcm-applied ; sum amount-of-current-cm-applied [t]
  total-cm-applied ; sum of amount-of-current-cm-applied [t]
  global-fraction-rmcm-applied ; average fraction over the simulation years
  concrete-rubble-demand ; demand for concrete rubble with amount-of-current-rmcm-applied in [t]
  mixed-rubble-demand ; demand for mixed rubble with amount-of-current-rmcm-applied in [t]
  ;RA-substitution-fraction ; fraction of recycled aggregates substituted, two scenarios min 25% and ref. 40% (Knoeri et al. 2012)
  ;RC-M-fraction ; fraction of recycled concrete which is RC-M (all lean concrete + a fraction of the rest => 10% overall) 
  ;recycling-efficiency ; efficiency of the recycling process, fraction of C&D waste usable as aggregates ca. 95% after (Knoeri et al 2012)
  
  ;RMCM availability
  annual-construction-waste-volume 
  annual-concrete-rubble-supply
  annual-mixed-rubble-supply
  
  total-num-projects ; all projects build during the simulation
  rmcm-project-fraction ;fraction of projects with rmcm
  
  
  
  ;agent specific variables
  
  ;define initial agent number
  initial-num-private-AA
  initial-num-commercial-AA
  initial-num-public-AA
  initial-num-architects
  initial-num-engineers
  initial-num-contractors
  
  ;Agents experience time in the interface
  ;agents-experience-time
  
  ;option availability settings defined in the interface
  ;private-AA-specification-availability
  ;commercial-AA-specification-availability
  ;public-AA-specification-availability
  ;engineers-specification-probability
  ;architects-recommendation-probability
  ;contractors-tender-probability
  
  RMCM-Image ;set according to the materials applied
  
]

;define agent breeds for AA, architects, engineers and contractors  
breed [awarding-authorities awarding-authority]
breed [architects architect]
breed [engineers engineer]
breed [contractors contractor]
;define project breeds only used within oune year
breed [projects project]

;define agent variables 
awarding-authorities-own [
  awarding-authority-type ;private, commercial, public
  construction-capacity ; maximum executable projects per year and AA  
  projects-to-do ;remaining projects to do
  projects-done
  building-radius ;radius within projects are built
  
  ;agent selection weights according to survey
  selection-reference-weight ;weight of rmcm reference projects, mean 0.4, std 0.25 from survey 
  selection-contact-weight ;weight of personal contact, (mean 0.6, std 0.25) but calculated 1 - selection-reference-weight
  
  ;project-specification variables
  specification-option-availability ;probability if the sustainable construction specification is made
  project-specification-economy ;economic aspects perception
  project-specification-economy-weight
  project-specification-ecology ; ecological aspects perception
  project-specification-ecology-weight
  project-specification-social ; social aspects perception
  project-specification-social-weight
  
  ;project confirmation variables
  project-confirmation-Arch-recommendation-weight
  project-confirmation-criterium-2 ;private expected price
  project-confirmation-criterium-2-weight
  project-confirmation-criterium-3 ;private technical aspects
  project-confirmation-criterium-3-weight
  project-confirmation-criterium-4 ;private ecological aspects
  project-confirmation-criterium-4-weight
  
 
  ;tender selection variables
  tender-selection-tender-doc-weight
  tender-selection-tender-price-weight
  tender-selection-Arch-recommendation-weight
  tender-selection-criterium-4
  tender-selection-criterium-4-weight
  
]

architects-own [
  ;selection parameter
  projects-together ;percentage of projects build with the selecting AA
  rmcm-experience ; percentage of projects in the last 5 years with rmcm
  ;project recommendation parameter
  specification-sensitivity ; probability of considering rmcm if AA specified SC or engineer specified rmcm
  project-recommendation-AA-project-spec-weight
  project-recommendation-expected-tender-price
  project-recommendation-expected-tender-price-weight
  project-recommendation-Eng-design-specification-weight
  project-recommendation-image
  project-recommendation-image-weight
  project-recommendation-aesthetics
  project-recommendation-aesthetics-weight
  ]

engineers-own[
  ;selection parameter
  projects-together; percentage of projects build with the selecting AA
  ;design-specification-parameter
  project-specification-sensitivity ; probability of considering rmcm if AA specifeid sustainable construction
  design-specification-AA-project-spec-weight
  design-specification-expected-price
  design-specification-expected-price-weight
  design-specification-experience
  design-specification-experience-weight
  design-specification-norms
  design-specification-norms-weight
  ]

contractors-own[
  ;project-tender-probability
  ;submission-weight
  tender-material ;type of material in the tender
  tender-price
  tender-utility ;tender utiity used to choose among contractors 
  rmcm-experience ; percentage of projects build with RMCM in the last 5 years
  ;tender submission parameter
  tender-submission-tender-doc-weight
  tender-submission-economic-aspects
  tender-submission-economic-aspects-weight
  tender-submission-experience
  tender-submission-experience-weight
  tender-submission-technical-aspects
  tender-submission-technical-aspects-weight
  ]


;define project variables
projects-own [ 
  construction-year
  investor ;private, commercial or public
  construction-sum ; construction sum in Mio CHF (with model relation of 1:100 each project is 100 time larger/heavier)
  project-specification ; 0 if no sustainability spec, 1 other vice
  design-specification 
  project-recommendation
  project-confirmation
  rmcm-tender ; if 1 RMCM are tendered
  tender-selection
  materials-applied ;RC 1, CC 0
  material-amount ; amount of concrete in [t]
  ;stakeholders
  my-awarding-authority
  my-engineer
  my-architect
  my-contractor
  ] 


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;experiment;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to experiment ;set all interface slider variables to their initial value 
  
  ;set global variables
  set initial-RMCM-application 0.08 ; 8 % of the structural concrete decisions 
  set RA-substitution-fraction 0.25 ; fraction of recycled aggregates substituted, two scenarios min 25% and ref. 40% (Knoeri et al. 2012)
  set RC-M-fraction 0.1 ; fraction of recycled concrete which is RC-M (all lean concrete + a fraction of the rest => 10% overall) 
  set recycling-efficiency 0.95 ; efficiency of the recycling process, fraction of C&D waste usable as aggregates ca. 95% after (Knoeri et al 2012)
  set Percental-RCtoCC-price-difference 0 ; 5% lower price for recycled concrete according to (Knoeri et al 2011)
  set agents-experience-time 5
  
  ;agent variables
  ;set awarding authorities' mean decision parameters
  ;project specification
  set private-AA-specification-availability 0.57 ; survey 0.57
  set commercial-AA-specification-availability 0.42 ; survey 0.42
  set public-AA-specification-availability 0.40 ; survey 0.40
  set SustainableConstructionSpecification-SocialAspects 0.75
  set SustainableConstructionSpecification-EconomicAspects 0.75
  set SustainableConstructionSpecification-EcologicalAspects 0.75
  ;project confirmation
  set PrivateProjectConfirmation-RMCMExpectedPrices 0.45
  set PrivateProjectConfirmation-RMCMTechnicalAspects 0.45
  set PrivateProjectConfirmation-RMCMEcologicalAspects 0.55
  set CommercialProjectConfirmation-RMCMEconomicAspects 0.45
  set CommercialProjectConfirmation-RMCMTechnicalAspects 0.50
  set CommercialProjectConfirmation-RMCMEcologicalAspects 0.50
  set PublicProjectConfirmation-RMCMExpectedPrices 0.40
  set PublicProjectConfirmation-RMCMPolicy 0.55  
  set PublicProjectConfirmation-RMCMImage 0.50
  ;project selection
  set PrivatTenderSelection-RMCMEcologicalAspects 0.60
  set CommercialTenderSelection-RMCMMarketability 0.40
  
  ;engineers' decision parameters
  set Engineers-project-spec-sensitivity 0.5
  set engineers-design-specification-probability 0.1 ; about the amount of initial rmcm project decisions
  set DesignSpecification-RMCMExpectedPrices 0.4
  set DesignSpecification-RMCMExperience 0.4
  set DesignSpecification-RMCMNorm 0.45
  
  ;architects' decision parameters
  set Architects-spec-sensitivity 0.5
  set architects-recommendation-probability 0.1 ; about the amount of initial rmcm project decisions
  set ProjectRecommendation-RMCMExpectedPrices 0.4
  set ProjectRecommendation-RMCMImage 0.45
  set ProjectRecommendation-RMCMAesthetics 0.35

  ;contractors' decision parameters
  set contractors-tender-probability 0.1 ; about the amount of initial rmcm project decisions
  set TenderSubmission-RMCMEconomicAspects 0.5
  set TenderSubmission-RMCMExperience 0.45
  set TenderSubmission-RMCMTechnicalAspects 0.4  


  ;do setup
  setup
   
  ;run the go procedure untill the simulation end year is reached
 ; while [simulation-time <= simulation-end-year] [
  ;  go
  ;]

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;SETUP;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
 
  clear-all ; clear all dump from simulation
  
  set simulation-time simulation-start-year
  
  ;set investment parameters
  set private-investment-fraction 0.323 ;stable accross time
  set commercial-investment-fraction 0.495 ;stable accross time
  set public-investment-fraction 0.182 ;stable accross time
  set mean-private-investment 84 ; mean investment of private AA, 0.840 Mio CHF model relation 1:100
  set mean-commercial-investment 116; mean investment of commercial AA, 1.155 Mio CHF model relation 1:100
  set mean-public-investment 97 ; mean investment of public AA, 0.969 Mio CHF model relation 1:100
  ;set mean AA construction probability (according to statistical data)
  set mean-private-AA-construction-capacity 0.03
  set mean-commercial-AA-construction-capacity 3
  set mean-public-AA-construction-capacity 10
  
  ;material flow parameters
  set mean-concrete-mass-per-investment 252 ;concrete mass [t] per mio CHF invested 252 Sdt 107 
  
  
  ask patches [set pcolor 52] ;set patch color green
  
  set current-fraction-rmcm-applied initial-RMCM-application
  set RMCM-Image current-fraction-rmcm-applied
  
  ;define agent number for agent initialization (relation according to statistical data) model relation 1:100 
  set initial-num-private-AA 5700 ;5700
  set initial-num-commercial-AA 83
  set initial-num-public-AA 5
  set initial-num-architects 46
  set initial-num-engineers 18 
  set initial-num-contractors 25
    
  ;initialize AA, architects, engineers and contractors
  setup-awarding-authorities
  setup-architects 
  setup-engineers
  setup-contractors
  
  reset-ticks
  
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;setup submodels;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-awarding-authorities
  ;create private awarding-authorities and set their initial parameter values  
  create-awarding-authorities initial-num-private-AA [
    set-random-agent-position  
    set color orange
    set size 1 
    set awarding-authority-type "private"
    ;set construction-capacity random-poisson mean-private-AA-construction-capacity ;about 170 projects per year with 5700 private AA
    set construction-capacity delimited-random-normal mean-private-AA-construction-capacity 0.012 
    ifelse random-float 1 < construction-capacity [set projects-to-do 1][set projects-to-do 0]
    set building-radius random-poisson 30 ; statistically 0.3 km with 1:100 scale => 30 units 
    set specification-option-availability private-AA-specification-availability
    
    ;agent selection weights according to survey
    set selection-reference-weight delimited-random-normal 0.4 0.25 ;weight of rmcm reference projects, mean 0.4, std 0.25 from survey 
    set selection-contact-weight 1 - selection-reference-weight ;weight of personal contact, (mean 0.6, std 0.25) but calculated 1 - selection-reference-weight
     
    ;set project specification decision parameters initially from the survey
    set project-specification-social delimited-random-normal SustainableConstructionSpecification-SocialAspects 0.17 ; 0 conventional material, 1 RMCM recommended
    set project-specification-social-weight delimited-random-normal 0.19 0.15 ;weight  
    set project-specification-economy delimited-random-normal SustainableConstructionSpecification-EconomicAspects 0.17 ; 0 conventional material, 1 RMCM recommended 
    set project-specification-economy-weight delimited-random-normal 0.39 0.20 ;weight
    set project-specification-ecology delimited-random-normal SustainableConstructionSpecification-EcologicalAspects 0.16 ; 0 conventional material, 1 RMCM recommended
    set project-specification-ecology-weight delimited-random-normal 0.42 0.18 ;weight
    
    ;set project confirmation decision parameters initially from the survey
    set project-confirmation-Arch-recommendation-weight delimited-random-normal 0.32 0.19
    ;set project-confirmation-expected-tender-price according to initial perception and Percental-RCtoCC-price-difference if AA price sensitive
    ifelse AA-price-sensitivity = true
      [set project-confirmation-criterium-2 delimited-random-normal ((PrivateProjectConfirmation-RMCMExpectedPrices + (0.5 - Percental-RCtoCC-price-difference)) / 2) 0.14]
      [set project-confirmation-criterium-2 delimited-random-normal PrivateProjectConfirmation-RMCMExpectedPrices 0.14]
    set project-confirmation-criterium-2-weight delimited-random-normal 0.23 0.14
    set project-confirmation-criterium-3 delimited-random-normal PrivateProjectConfirmation-RMCMTechnicalAspects 0.18
    set project-confirmation-criterium-3-weight delimited-random-normal 0.26 0.13
    set project-confirmation-criterium-4 delimited-random-normal PrivateProjectConfirmation-RMCMEcologicalAspects 0.20
    set project-confirmation-criterium-4-weight delimited-random-normal 0.19 0.14
    
    ;set tender selection decision parameters initially from the survey
    set tender-selection-tender-doc-weight delimited-random-normal 0.20 0.15
    set tender-selection-tender-price-weight delimited-random-normal 0.27 0.14 
    set tender-selection-Arch-recommendation-weight delimited-random-normal 0.32 0.16 ;technical aspects (arch recommendation)
    set tender-selection-criterium-4 delimited-random-normal PrivatTenderSelection-RMCMEcologicalAspects 0.25 ;ecological aspects
    set tender-selection-criterium-4-weight delimited-random-normal 0.21 0.16

  ]
  
  ;create commercial awarding-authorities and set their initial parameter values  
  create-awarding-authorities initial-num-commercial-AA [
    set-random-agent-position  
    set color orange
    set size 1 
    set awarding-authority-type "commercial"
    set construction-capacity random-poisson mean-commercial-AA-construction-capacity ;about 230 projects per year with 86 commercial AA
    set projects-to-do construction-capacity
    set building-radius random-poisson 30 ; statistically 0.3 km with 1:100 scale => 30 units 
    set specification-option-availability commercial-AA-specification-availability
    
    ;agent selection weights according to survey
    set selection-reference-weight delimited-random-normal 0.4 0.25 ;weight of rmcm reference projects, mean 0.4, std 0.25 from survey 
    set selection-contact-weight 1 - selection-reference-weight ;weight of personal contact, (mean 0.6, std 0.25) but calculated 1 - selection-reference-weight
    
    ;set project specification decision parameters initially from the survey
    set project-specification-social delimited-random-normal SustainableConstructionSpecification-SocialAspects 0.17 ; 0 conventional material, 1 RMCM recommended
    set project-specification-social-weight delimited-random-normal 0.30 0.19 ;weight  
    set project-specification-economy delimited-random-normal SustainableConstructionSpecification-EconomicAspects 0.17 ; 0 conventional material, 1 RMCM recommended
    set project-specification-economy-weight delimited-random-normal 0.41 0.18 ;weight
    set project-specification-ecology delimited-random-normal SustainableConstructionSpecification-EcologicalAspects 0.16 ; 0 conventional material, 1 RMCM recommended
    set project-specification-ecology-weight delimited-random-normal 0.29 0.17 ;weight
    
    ;set project confirmation decision parameters initially from the survey
    set project-confirmation-Arch-recommendation-weight delimited-random-normal 0.32 0.19
    ;set project-confirmation-expected-tender-price according to initial perception and Percental-RCtoCC-price-difference if AA price sensitive
    ifelse AA-price-sensitivity = true
      [set project-confirmation-criterium-2 delimited-random-normal ((CommercialProjectConfirmation-RMCMEconomicAspects + (0.5 - Percental-RCtoCC-price-difference)) / 2) 0.14]
      [set project-confirmation-criterium-2 delimited-random-normal CommercialProjectConfirmation-RMCMEconomicAspects 0.14]
    set project-confirmation-criterium-2-weight delimited-random-normal 0.45 0.22
    set project-confirmation-criterium-3 delimited-random-normal CommercialProjectConfirmation-RMCMTechnicalAspects 0.17
    set project-confirmation-criterium-3-weight delimited-random-normal 0.23 0.11
    set project-confirmation-criterium-4 delimited-random-normal CommercialProjectConfirmation-RMCMEcologicalAspects 0.20
    set project-confirmation-criterium-4-weight delimited-random-normal 0.19 0.14
    
    ;set tender selection decision parameters initially from the survey
    set tender-selection-tender-doc-weight delimited-random-normal 0.16 0.15
    set tender-selection-tender-price-weight delimited-random-normal 0.28 0.14 
    set tender-selection-Arch-recommendation-weight delimited-random-normal 0.34 0.12 ;technical aspects (arch recommendation)
    set tender-selection-criterium-4 delimited-random-normal CommercialTenderSelection-RMCMMarketability 0.18 ;ecological aspects
    set tender-selection-criterium-4-weight delimited-random-normal 0.22 0.11
    
  ]
  
  ;create public awarding-authorities and set their initial parameter values  
  create-awarding-authorities initial-num-public-AA [
    set-random-agent-position  
    set color orange
    set size 1 
    set awarding-authority-type "public"
    set construction-capacity random-poisson mean-public-AA-construction-capacity ;about 50 projects per year with 5 public AA
    set projects-to-do construction-capacity
    set building-radius random-poisson 50 ; statistically 0.5 km with 1:100 scale => 50 units 
    set specification-option-availability public-AA-specification-availability
    
    ;agent selection weights according to survey
    set selection-reference-weight delimited-random-normal 0.4 0.25 ;weight of rmcm reference projects, mean 0.4, std 0.25 from survey 
    set selection-contact-weight 1 - selection-reference-weight ;weight of personal contact, (mean 0.6, std 0.25) but calculated 1 - selection-reference-weight
    
    ;set project specification decision criteria weights according to survey
    set project-specification-social delimited-random-normal SustainableConstructionSpecification-SocialAspects 0.17 ; 0 conventional material, 1 RMCM recommended
    set project-specification-social-weight delimited-random-normal 0.26 0.16    
    set project-specification-economy delimited-random-normal SustainableConstructionSpecification-EconomicAspects 0.17 ; 0 conventional material, 1 RMCM recommended
    set project-specification-economy-weight delimited-random-normal 0.39 0.17 
    set project-specification-ecology delimited-random-normal SustainableConstructionSpecification-EcologicalAspects 0.16 ; 0 conventional material, 1 RMCM recommended
    set project-specification-ecology-weight delimited-random-normal 0.35 0.17 
    
    ;set project confirmation decision parameters initially from the survey
    set project-confirmation-Arch-recommendation-weight delimited-random-normal 0.32 0.19
    ;set project-confirmation-expected-tender-price according to initial perception and Percental-RCtoCC-price-difference if AA price sensitive
    ifelse AA-price-sensitivity = true
      [set project-confirmation-criterium-2 delimited-random-normal ((PublicProjectConfirmation-RMCMExpectedPrices + (0.5 - Percental-RCtoCC-price-difference)) / 2) 0.14]
      [set project-confirmation-criterium-2 delimited-random-normal PublicProjectConfirmation-RMCMExpectedPrices 0.14]
    set project-confirmation-criterium-2-weight delimited-random-normal 0.23 0.14
    set project-confirmation-criterium-3 delimited-random-normal PublicProjectConfirmation-RMCMPolicy 0.14
    set project-confirmation-criterium-3-weight delimited-random-normal 0.26 0.13
    ifelse Image-usage-sensitivity = true
      [set project-confirmation-criterium-4 delimited-random-normal RMCM-image 0.15]
      [set project-confirmation-criterium-4 delimited-random-normal PublicProjectConfirmation-RMCMImage 0.15]
    set project-confirmation-criterium-4-weight delimited-random-normal 0.19 0.14
    
    ;set tender selection decision parameters for public AA predefined and mainly price, initially from the survey
    set tender-selection-tender-doc-weight 0 ; not considered for public AA 
    set tender-selection-tender-price-weight delimited-random-normal 0.75 0.25 
    set tender-selection-Arch-recommendation-weight 0 ;not considered for public AA 
    set tender-selection-criterium-4-weight delimited-random-normal 0.25 0.15 ; Contractors refereces
    
  ]
    
end


to setup-architects
  ;create engineers and set their initial parameter values
  create-architects initial-num-architects [
    set-random-agent-position
    set color blue
    set size 1
    
    ;set selection parameters
    set rmcm-experience delimited-random-normal initial-rmcm-application 0.05 ; initially set arround the current demand 
    
    ;set option awareness parameters
    set specification-sensitivity delimited-random-normal Architects-spec-sensitivity 0.2
    
    
    ;set project recommedation decision parameters initially from survey
    set project-recommendation-AA-project-spec-weight delimited-random-normal 0.14 0.09
    ;set project-recommendation-expected-tender-price according to initial perception and Percental-RCtoCC-price-difference if Expert price sensitive
    ifelse Expert-price-sensitivity = true
      [set project-recommendation-expected-tender-price delimited-random-normal ((ProjectRecommendation-RMCMExpectedPrices + (0.5 - Percental-RCtoCC-price-difference)) / 2) 0.15]
      [set project-recommendation-expected-tender-price delimited-random-normal ProjectRecommendation-RMCMExpectedPrices 0.15]  ;0 conventional material, 1 RMCM recommended   
    set project-recommendation-expected-tender-price-weight delimited-random-normal 0.21 0.11 
    set project-recommendation-Eng-design-specification-weight delimited-random-normal 0.28 0.12 
    ifelse Image-usage-sensitivity = true
      [set project-recommendation-image delimited-random-normal RMCM-image 0.17]
      [set project-recommendation-image delimited-random-normal ProjectRecommendation-RMCMImage 0.17] ;0 conventional material, 1 RMCM recommended   
    set project-recommendation-image-weight delimited-random-normal 0.16 0.07
    set project-recommendation-aesthetics delimited-random-normal ProjectRecommendation-RMCMAesthetics 0.17 ;0 conventional material, 1 RMCM recommended   
    set project-recommendation-aesthetics-weight delimited-random-normal 0.21 0.08 
    

    
  ]
end
  

to setup-engineers
  ;create engineers and set their initial parameter values
  create-engineers initial-num-engineers [
    set-random-agent-position
    set color yellow
    set size 1
    ;set option awareness parameters
    set project-specification-sensitivity delimited-random-normal Engineers-project-spec-sensitivity 0.2
    
    ;set design specification decision parameters initially from survey
    set design-specification-AA-project-spec-weight delimited-random-normal 0.19 0.15
    ;set design-specification-expected-price according to initial perception and Percental-RCtoCC-price-difference if experts are price sensitve
    ifelse Expert-price-sensitivity = true
      [set design-specification-expected-price delimited-random-normal ((DesignSpecification-RMCMExpectedPrices + (0.5 - Percental-RCtoCC-price-difference)) / 2) 0.19]
      [ set design-specification-expected-price delimited-random-normal DesignSpecification-RMCMExpectedPrices 0.19]  ;0 conventional material, 1 RMCM recommended  
    set design-specification-expected-price-weight delimited-random-normal 0.20 0.14 
    set design-specification-experience delimited-random-normal DesignSpecification-RMCMExperience 0.15 ;0 conventional material, 1 RMCM recommended 
    set design-specification-experience-weight delimited-random-normal 0.26 0.13 
    set design-specification-norms delimited-random-normal DesignSpecification-RMCMNorm 0.17 ;0 conventional material, 1 RMCM recommended
    set design-specification-norms-weight delimited-random-normal 0.36 0.17   
       
  ]
end


to setup-contractors
  ;create contractors and set their initial parametervalues
  create-contractors initial-num-contractors [
    set-random-agent-position
    set color magenta
    set size 1
    
    ;set selection parameters
    set rmcm-experience delimited-random-normal initial-rmcm-application 0.05 ; initially set arround the current demand 

    
    ;set tender sumission decision parameters initially from survey
    set tender-submission-tender-doc-weight delimited-random-normal 0.37 0.18
    ;set tender-submission-economic-aspects according to initial perception and Percental-RCtoCC-price-difference if experts are price sensitve
    ifelse Expert-price-sensitivity = true
      [set tender-submission-economic-aspects delimited-random-normal ((TenderSubmission-RMCMEconomicAspects + (1 - Percental-RCtoCC-price-difference) / 2)) 0.2]
      [set tender-submission-economic-aspects delimited-random-normal TenderSubmission-RMCMEconomicAspects 0.2]  ;0 conventional material, 1 RMCM recommended  
    set tender-submission-economic-aspects-weight delimited-random-normal 0.18 0.11
    set tender-submission-experience delimited-random-normal TenderSubmission-RMCMExperience 0.2 ;0 conventional material, 1 RMCM recommended
    set tender-submission-experience-weight delimited-random-normal 0.24 0.12
    set tender-submission-technical-aspects delimited-random-normal TenderSubmission-RMCMTechnicalAspects 0.2 ;0 conventional material, 1 RMCM recommended
    set tender-submission-technical-aspects-weight delimited-random-normal 0.21 0.12   
  ] 
end


;set agent on a patch were nobody is
to set-random-agent-position
  let open-position true
  while [open-position] [
    let x round random-xcor
    let y round random-ycor
    ;check if there are any turtles
    if count turtles-at x y = 0 [
      setxy x y
      set open-position false ; quit while loop
    ]
  ]
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;EXECUTION;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to go
  
  
  if simulation-time > simulation-end-year [stop]
  
  calculate-investments-and-create-projects ;calculate annual investments and create this-years-projects related to awarding authorities investment shares
  
  let this-years-projects projects with [construction-year = simulation-time]   ;build set of current projects
  set total-num-projects total-num-projects + count this-years-projects
  
  calculate-RC-supply ;calculate annual potential supply of recycled concrete
  
  distribute-and-execute-projects this-years-projects  ; distribute projects to AA, encrease AA construction potential if to small and execute projects randomly
  
  set-global-demand-parameters this-years-projects  ; update global demand values
  
  ;update agent properties
  update-awarding-authorities
  update-architect-properties
  update-engineer-properties
  update-contractor-properties
  
  ;delete projects older than agents-experience-time
  ask projects with [construction-year < (simulation-time - agents-experience-time)] [die]
 

  ;increase time
  tick
  set simulation-time simulation-start-year + ticks
  
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;SUBMODEL;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;CALCULATE INVESTEMENTS AND CREATE PROJECTS;;;;;;;;;;;;;;;;;;;;;;;;;;

to calculate-investments-and-create-projects
  
  ;calculate annual construction investment in Mio CHF
  set annual-construction-investment (2.63E4 * (simulation-time - 1994) ^ 0.206) ; annual-construction-investment power law trend exploration
      + ((investment-scenario * 17) * ((simulation-time - 1994 - 14) ^ 2 )) ;investment scenarions after 2008 
  ;show annual-construction-investment
  let private-investment annual-construction-investment * private-investment-fraction
  let commercial-investment annual-construction-investment * commercial-investment-fraction
  let public-investment annual-construction-investment * public-investment-fraction
  ;show private-investment + commercial-investment + public-investment
  
  ;create private projects while private investment is larger than 0
  while [private-investment > 0] [  
    create-projects 1 [
      ;set project properties
      set shape "house"
      set size 0
      set color red
      set construction-year simulation-time
      set investor "private"
      ; set construction sum
      let sum-set false
      while [sum-set = false][
        set construction-sum random-normal mean-private-investment 39 ; StD with model relation 1:100
        if construction-sum > private-investment [set construction-sum private-investment] ; set to the remaining monney
        if construction-sum > 0 [set sum-set true]] ; ensure positive investements 
      set private-investment private-investment - construction-sum
    ]  
  ]
  
  ;create commercial projects while commercial investment is larger than 0
  while [commercial-investment > 0] [  
    create-projects 1 [
      ;set project properties
      set shape "house"
      set size 0
      set color red
      set construction-year simulation-time
      set investor "commercial"
      ; set construction sum
      let sum-set false
      while [sum-set = false][
        set construction-sum random-normal mean-commercial-investment 25 ; StD with model relation 1:100
        if construction-sum > commercial-investment [set construction-sum commercial-investment] ; set to the remaining monney
        if construction-sum > 0 [set sum-set true]] ; ensure positive investements 
      set commercial-investment commercial-investment - construction-sum    
    ]  
  ]
  
  ;create public projects while commercial investment is larger than 0
  while [public-investment > 0] [  
    create-projects 1 [
      ;set project properties
      ;set shape "house"
      ;set size 0
      ;set color red
      set construction-year simulation-time
      set investor "public"
      ; set construction sum
      let sum-set false
      while [sum-set = false][
        set construction-sum random-normal mean-public-investment 43 ; StD with model relation 1:100
        if construction-sum > public-investment [set construction-sum public-investment] ; set to the remaining monney
        if construction-sum > 0 [set sum-set true]] ; ensure positive investements 
      set public-investment public-investment - construction-sum   
    ]  
  ]
  
  ;show sum [construction-sum] of projects with [construction-year = simulation-time] ; debugging print out
   
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;CALCULATE POTENTIAL RC SUPPLY;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to calculate-RC-supply
  
  ;reset demand
  set concrete-rubble-demand 0
  set mixed-rubble-demand 0
  
  ;calculate inital potential annual waste volumes in Mio t
  set annual-construction-waste-volume (3.025E6 * ((simulation-time - 1994) ^ 0.11605)) ; annual-construction-waste-volume power law trend exploration
      + ((investment-scenario * 800) * ((simulation-time - 1994 - 14) ^ 2 )) ;waste scenarions after 2008 
  ;show annual-construction-waste-volume
  let concrete-waste-fraction 0.1524 ; concrete waste fraction in % by volume
  let concrete-waste-density 2.4 ; 2.4 t/m3 
  let residual-mineral-waste-fraction 0.5964 ; roads, masonry and mineral waste fraction in % by volume
  let residual-waste-density  1.632 ;1.632 t/m3
  set annual-concrete-rubble-supply annual-construction-waste-volume * concrete-waste-fraction * concrete-waste-density * recycling-efficiency
  set annual-mixed-rubble-supply annual-construction-waste-volume * residual-mineral-waste-fraction * residual-waste-density * recycling-efficiency
  ;show annual-concrete-rubble-supply
  ;show annual-mixed-rubble-supply

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DISTRIBUTE AND EXECUTE PROJECTS WITH ENOUGH AWARDING AUTHORITIES;;;;;;;;;;;;;;;;;;

to distribute-and-execute-projects [this-years-projects]
  
  ;ensure enough construction capycity in the system
  
  ;show count this-years-projects with [investor = "private"]
  ;show sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "private"]
  while [count this-years-projects with [investor = "private"] > sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "private"] ] [
    ask one-of awarding-authorities with [projects-to-do = 0 and awarding-authority-type = "private"][set projects-to-do 1]
  ]
  ;show count this-years-projects with [investor = "commercial"]
  ;show sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "commercial"]
  while [count this-years-projects with [investor = "commercial"] > sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "commercial"] ] [
    ask one-of awarding-authorities with [awarding-authority-type = "commercial"][set projects-to-do projects-to-do + 1]
  ]
  ;show count this-years-projects with [investor = "public"]
  ;show sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "public"]
  while [count this-years-projects with [investor = "public"] > sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "public"] ] [
    ask one-of awarding-authorities with [awarding-authority-type = "public"][set projects-to-do projects-to-do + 1]
  ]
  
  
  ;distribute the projects to the AA and execute
    
  ask this-years-projects [
    let this-project self
    ask one-of awarding-authorities with [projects-to-do >= 1 and awarding-authority-type = [investor] of myself] [
      set projects-to-do projects-to-do - 1
      ask this-project [
        set material-amount construction-sum * (random-normal mean-concrete-mass-per-investment 107)
        if material-amount < 0 [set material-amount 0] ;avoid negative material amounts
        set my-awarding-authority myself
        move-to patch [xcor] of myself [ycor] of myself
        move-to one-of patches in-radius ([building-radius] of myself) with [not any? projects-here] ;set position in building-radius around the agent on a free spot 
        execute-project
      ] 
    ]
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;EXECUTE PROJECTS;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to execute-project ;this is a awarding authorities procedure called within the hatch projects procedure
  
  let this-project self
  let AA myself
  
  make-project-specification 
  
  select-engineer-for-design-specification this-project AA
  
  select-architect-for-project-recommendation this-project AA  
   
  make-project-confirmation this-project  
  
  ;select 3 closest contractors for tendering out of 25
  let potential-contractors min-n-of 3 contractors [distance myself]
  ask potential-contractors [make-an-offer this-project] ;set tender variable acording to the current project
  
  ;select among the cont ractors
  make-tender-selection this-project potential-contractors AA
                     
  ;deduct the amount of rmcm applied from the available rmcm if still available
  if tender-selection = 1 [ 
    ;if enough both rubble is still available demand two fractions
    if ((1 - RC-M-fraction) * 0.75 * material-amount) < (annual-concrete-rubble-supply - concrete-rubble-demand) and
       (RC-M-fraction * 0.75 * material-amount) < (annual-mixed-rubble-supply - mixed-rubble-demand) ; aggregates 1.9 tons (75% by weight) aggregates per m3 concrete
          [set concrete-rubble-demand concrete-rubble-demand + (1 - RC-M-fraction) * 0.75 * material-amount * RA-substitution-fraction * 1.1 ; 10% overdose
           set mixed-rubble-demand mixed-rubble-demand + RC-M-fraction * 0.75 * material-amount * RA-substitution-fraction * 1.2] ; 20% substitution 
    ;if only mixed rubble is available demand all RC-M
    if (0.75 * material-amount) > (annual-concrete-rubble-supply - concrete-rubble-demand) and
       (0.75 * material-amount) < (annual-mixed-rubble-supply - mixed-rubble-demand) 
          [set mixed-rubble-demand mixed-rubble-demand + 0.75 * material-amount * RA-substitution-fraction * 1.2]
    ; if only concrete rubble available demand all RC-C
    if (0.75 * material-amount) < (annual-concrete-rubble-supply - concrete-rubble-demand) and
       (0.75 * material-amount) > (annual-mixed-rubble-supply - mixed-rubble-demand) ; aggregates 1.9 tons (75% by weight) aggregates per m3 concrete
          [set concrete-rubble-demand concrete-rubble-demand + 0.75 * material-amount * RA-substitution-fraction * 1.1]
    ; if both unavailable demand cc
    if (0.75 * material-amount) > (annual-concrete-rubble-supply - concrete-rubble-demand) and
       (0.75 * material-amount) > (annual-mixed-rubble-supply - mixed-rubble-demand) ; aggregates 1.9 tons (75% by weight) aggregates per m3 concrete
          [set tender-selection 0] 
  ]
    
  ;set materials-applied
  set materials-applied tender-selection
  
  ifelse materials-applied = 1 ;pcolor according to materials applied
    [set pcolor white] 
    [set pcolor black]
  
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;DECISION SUBMODELS;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;make project-specification;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to make-project-specification ;AA procedure
  
  ifelse random-float 1 < [specification-option-availability] of myself ;make decision if SCS is an option
  
    ;make decision
    [;compare project-specification of suctainable construction with the conventional option
    ifelse ([project-specification-social] of myself * [project-specification-social-weight] of myself +
            [project-specification-economy] of myself * [project-specification-economy-weight] of myself +
            [project-specification-ecology] of myself * [project-specification-ecology-weight] of myself )
            >
            (1 - [project-specification-social] of myself) * [project-specification-social-weight] of myself +
            (1 - [project-specification-economy] of myself) * [project-specification-economy-weight] of myself +
            (1 - [project-specification-ecology] of myself) * [project-specification-ecology-weight] of myself
        ;make it discrete
        [set project-specification 1][set project-specification 0]]
    ;other vice
    [set project-specification 0]
   
  ;show word "Project spezification is " project-specification
  
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;select engineer for design specification;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to select-engineer-for-design-specification [this-project AA]
  
  ;select engineer for design-specification among the 5 closest engineers out of 18
  let potential-engineers min-n-of 5 engineers [distance AA]
  ;ask potential engineers to set their contact values (percentage of my-projects in the last agent-experience-time years build together)
  ask potential-engineers [set projects-together (1 + count projects with [my-awarding-authority = AA and my-engineer = myself and construction-year > (simulation-time - agents-experience-time)])
                           / (1 + count projects with [my-awarding-authority = AA and construction-year > (simulation-time - agents-experience-time)])]
  ;select according to project specification if sustainable construction specified other vice select just according to contact
  ifelse project-specification = 1
    [ask max-one-of potential-engineers [[selection-reference-weight] of AA * design-specification-experience + [selection-contact-weight] of AA * projects-together] 
      [make-design-specification this-project]]
    [ask max-one-of potential-engineers [projects-together] 
      [make-design-specification this-project]]
    
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;ask selected engineer to make design-specification;;;;;;;;;;;;;;;;;;;;
  
to make-design-specification [this-project] ;engineer procedure
  
  ask this-project [
    set my-engineer myself
    ifelse (project-specification = 1 and (random-float 1 < [project-specification-sensitivity] of myself)) or ;make decision if SCS input from the AA and sensitive to it or
      (project-specification = 0 and (random-float 1 < engineers-design-specification-probability)) ;in a percentage of all other cases
      
      ;make decision 
      [;simplified design specification compare rc with cc only and distribute open spec option 
      ifelse (project-specification * [design-specification-AA-project-spec-weight] of myself +
             [design-specification-expected-price] of myself * [design-specification-expected-price-weight] of myself +
             [design-specification-experience] of myself * [design-specification-experience-weight] of myself +
             [design-specification-norms] of myself * [design-specification-norms-weight] of myself) 
             >
             ((1 - project-specification) * [design-specification-AA-project-spec-weight] of myself +
             (1 - [design-specification-expected-price] of myself) * [design-specification-expected-price-weight] of myself +
             (1 - [design-specification-experience] of myself) * [design-specification-experience-weight] of myself +
             (1 - [design-specification-norms] of myself) * [design-specification-norms-weight] of myself) 
          ;make it descrete
          [set design-specification 1][set design-specification 0]]
      
      ;othervise specify cm
      [set design-specification 0]
  ]
 
  ;show word "Engineer make design specification " [design-specification] of this-project
  
end


;;;;;;;;;;;;;;;;;;;;;;;select architect for project recommendation::::::::::::::::::::::::::::::::::::::::

to select-architect-for-project-recommendation [this-project AA]
 
  ;select architect for project recommendation amoung the 5 closest architects out of 46
  let potential-architects min-n-of 5 architects [distance AA]
  ;ask potential architects to set their contact values (percentage of my-projects in the last agent-experience-time years build together)
  ask potential-architects [set projects-together (1 + count projects with [my-awarding-authority = AA and my-architect = myself and construction-year > (simulation-time - agents-experience-time)])
                           / (1 + count projects with [my-awarding-authority = AA and construction-year > (simulation-time - agents-experience-time)])]
  ;select according to project specification if sustainable construction specified other vice select just according to contact
  ifelse project-specification = 1
    [ask max-one-of potential-architects [[selection-reference-weight] of AA * rmcm-experience + [selection-contact-weight] of AA * projects-together] 
      [make-project-recommendation this-project]]
    [ask max-one-of potential-architects [projects-together] 
      [make-project-recommendation this-project]]


end

;;;;;;;;;;;;;;;;;;;;;;;ask selected architect to do project-recommendation;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to make-project-recommendation [this-project] ;architect procedure
  
  ask this-project [ ; project context
    set my-architect myself
    ifelse ((project-specification = 1 or design-specification = 1) and (random-float 1 < [specification-sensitivity] of myself)) or ;make decision if SCS input from the AA or if engineer specified rmcm and sensitive to it 
           (project-specification = 0 and design-specification = 0 and (random-float 1 < architects-recommendation-probability)) ;in a percentage of all other cases
      
      ;include the engineers recommendation and AA project specification as external criteria
      [;show [sustainability-discussed] of this-project
      ifelse (project-specification * [project-recommendation-AA-project-spec-weight] of myself +
             [project-recommendation-expected-tender-price] of myself * [project-recommendation-expected-tender-price-weight] of myself +
             design-specification * [project-recommendation-Eng-design-specification-weight] of myself +   
             [project-recommendation-image] of myself * [project-recommendation-image-weight] of myself +
             [project-recommendation-aesthetics] of myself * [project-recommendation-aesthetics-weight] of myself) 
             > 
             ((1 - project-specification) * [project-recommendation-AA-project-spec-weight] of myself +
             (1 - [project-recommendation-expected-tender-price] of myself) * [project-recommendation-expected-tender-price-weight] of myself +
             (1 - design-specification) * [project-recommendation-Eng-design-specification-weight] of myself +   
             (1 - [project-recommendation-image] of myself) * [project-recommendation-image-weight] of myself +
             (1 - [project-recommendation-aesthetics] of myself) * [project-recommendation-aesthetics-weight] of myself)       
         ;make it descrete
         [set project-recommendation 1][set project-recommendation 0]]
      
      ;othervise recommend cm
      [set project-recommendation 0]
  ]
  ;show word "Architects recommendation is " [project-recommendation] of this-project
  
end


;;;;;;;;;;;;;;;;;;;;;;;;do project confirmation;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
to make-project-confirmation [this-project] 
  
  ifelse [project-specification] of this-project = 1 or ;make decision if I specified SCS input 
    ([design-specification] of this-project = 1) or ;the engineer specified rmcm or 
    ([project-recommendation] of this-project = 1) ;if architect recommended rmcm no additional rmcmc input if no mentioned so far in the project
    
    ;make decision 
    [
     ifelse ([project-recommendation] of this-project * [project-confirmation-Arch-recommendation-weight] of myself +
            [project-confirmation-criterium-2] of myself * [project-confirmation-criterium-2-weight] of myself +
            [project-confirmation-criterium-3] of myself * [project-confirmation-criterium-3-weight] of myself +
            [project-confirmation-criterium-4] of myself * [project-confirmation-criterium-4-weight] of myself) 
            >
            ((1 - [project-recommendation] of this-project) * [project-confirmation-Arch-recommendation-weight] of myself +
            (1 - [project-confirmation-criterium-2] of myself) * [project-confirmation-criterium-2-weight] of myself +
            (1 - [project-confirmation-criterium-3] of myself) * [project-confirmation-criterium-3-weight] of myself +
            (1 - [project-confirmation-criterium-4] of myself) * [project-confirmation-criterium-4-weight] of myself) 
        ;make it descrete
        [set project-confirmation  1][set project-confirmation  0]]              
  
    ;other vice specify cm in the tender docs
    [set project-confirmation  0]
  
  ;show word "Awarding authorities recommendation is " [project-confirmation] of this-project

end



;;;;;;;;;;;;;;;;;;; ask selected contractors to get their offer;;;;;;;;;;;;;;;;;;;;;;;;;

to make-an-offer [this-project]
 
  let my-tender-material 0
  ask this-project [
    
    ifelse project-confirmation = 1 or ;make decision if I rmcm are specified in the tender documents or
      ((project-confirmation = 0 and (random-float 1 < contractors-tender-probability)) and ;in a percentage of all other cases only if available
      ((concrete-rubble-demand < annual-concrete-rubble-supply) or (mixed-rubble-demand < annual-mixed-rubble-supply)))
      
      ;make material decision
      [ifelse (project-confirmation * [tender-submission-tender-doc-weight] of myself +
              [tender-submission-economic-aspects] of myself * [tender-submission-economic-aspects-weight] of myself +
              [tender-submission-experience] of myself * [tender-submission-experience-weight] of myself +
              [tender-submission-technical-aspects] of myself * [tender-submission-technical-aspects-weight] of myself) 
              > 
              ((1 - project-confirmation) * [tender-submission-tender-doc-weight] of myself +
              (1 - [tender-submission-economic-aspects] of myself) * [tender-submission-economic-aspects-weight] of myself +
              (1 - [tender-submission-experience] of myself) * [tender-submission-experience-weight] of myself +
              (1 - [tender-submission-technical-aspects] of myself) * [tender-submission-technical-aspects-weight] of myself) 
          ;make it descrete
          [set my-tender-material 1][set my-tender-material 0]] 
      ;other vice specify cm in the tender docs
      [set my-tender-material 0]    
    ;indicate ithat RMCM are tendered used for plotting the projects with rmcm tenders
    if rmcm-tender = 0 [set rmcm-tender my-tender-material]
  ]
  set tender-material my-tender-material
  ;show tender-material
  
  ;set tender price according to the chosen material and the global price difference, and a sdt of 5% (i.e. same market prices result in max 10% differing contractor prices)
  ;since price is not real price but a normalized price comparison a negative Percental-RCtoCC-price-difference results in a higher/better tender-price value
  ifelse tender-material = 1
    [set tender-price delimited-random-normal (0.5 - Percental-RCtoCC-price-difference) 0.05 ]
    [set tender-price delimited-random-normal (0.5 + Percental-RCtoCC-price-difference) 0.05 ]         
  ;show word "Contractors tender price is " tender-price   
  
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;do project tender selection;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to make-tender-selection [this-project potential-contractors AA]
  
  ifelse sum [tender-material] of potential-contractors > 0 ;make decision if I rmcm are specified in one of the tenders
      
    ;calculate the tender utilities of the potential contractors considering tender docs, tender-price, the architects recommendation and AAs' own preference
    [;show sum [tender-material] of potential-contractors
      ask potential-contractors [
        ;change criterium 4 for public AA to contractors RMCM reference
        let criterium-4 [tender-selection-criterium-4] of AA
        if [awarding-authority-type] of AA = "public" [
          set criterium-4 rmcm-experience
          ;show word "contractors rmcm experience is " criterium-4
          ]
        set tender-utility ([project-confirmation] of this-project * [tender-selection-tender-doc-weight] of AA +
                           tender-price * [tender-selection-tender-price-weight] of AA +
                           [project-recommendation] of this-project * [tender-selection-Arch-recommendation-weight] of AA +
                           criterium-4 * [tender-selection-criterium-4-weight] of AA)
        ;show tender-utility
      ]
      set my-contractor max-one-of potential-contractors [tender-utility] 
      set tender-selection [tender-material] of my-contractor
      ;show [tender-utility] of max-one-of potential-contractors [tender-utility]
    ]
    
    ;other vice demand cm with the contractor with the best price
    [set my-contractor max-one-of potential-contractors [tender-price]
     set tender-selection [tender-material] of my-contractor]  
  
    ;show tender-selection

end

;;;;;;;;;;;;;;;;;;;;;;;;;;MATHEMATICAL_REPORTERS;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;reports a random normal value to a given mean and StD between 0 and 1

to-report delimited-random-normal [a-mean a-std]
  let value 0 
  let value-set false
  while [value-set = false] [
    set value random-normal a-mean a-std
    if value > 0 and value < 1 [set value-set true] ;check if between 0 and 1
    ]
  report value
end 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;UPDATE SYSTEM DEMAND;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to set-global-demand-parameters [this-years-projects]
  
  set amount-of-current-rmcm-applied sum [material-amount] of this-years-projects with [materials-applied = 1]
  set amount-of-current-cm-applied sum [material-amount] of this-years-projects with [materials-applied = 0]
  set current-fraction-rmcm-applied sum [material-amount] of this-years-projects with [materials-applied = 1] / sum [material-amount] of this-years-projects
  ;show current-fraction-rmcm-applied    
  
  set rmcm-project-fraction count this-years-projects with [materials-applied = 1] / count this-years-projects
  
  set RMCM-Image current-fraction-rmcm-applied
  
  ;all time demand
  set total-rmcm-applied total-rmcm-applied + amount-of-current-rmcm-applied   ;sum up the total amount of rmcm applied 
  set total-cm-applied total-cm-applied + amount-of-current-cm-applied   ;sum up the total amount of cm applied 
  set global-fraction-rmcm-applied total-rmcm-applied / (total-rmcm-applied + total-cm-applied)   ;calculate avarage demand over time
  ;show global-fraction-rmcm-applied 

end

;;;;;;;;;;;;;;;;;;;;;;;;;;UPDATE AGENT PROPERTIES;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to update-awarding-authorities
  
  ask awarding-authorities [  
    ifelse awarding-authority-type = "private" 
       [set construction-capacity delimited-random-normal mean-private-AA-construction-capacity 0.012 
        ifelse random-float 1 < construction-capacity [set projects-to-do 1][set projects-to-do 0]] ;set probabilistically for private AA
       [set projects-to-do construction-capacity] ;reset projects-to-do for commercial and public AA  
       
       
    if Image-usage-sensitivity = true and awarding-authority-type = "public" 
      [set project-confirmation-criterium-4 delimited-random-normal RMCM-image 0.15] ;adjust image parameter
       
  ]
  ;debugging prints
  ;show sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "private"]
  ;show sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "commercial"]
  ;show sum [projects-to-do] of awarding-authorities with [awarding-authority-type = "public"]
  
end


to update-architect-properties
  
  ask architects [ ;update rmcm-experience according to the materials applied in the last agents-experience-time years
    let my-materials-applied [materials-applied] of projects with [my-architect = myself] ;list the materials applied in my projects
    if length my-materials-applied > 0 [ ;update experience only if any projects done
      set rmcm-experience (rmcm-experience * ((1 + (sum my-materials-applied / length my-materials-applied)) / ( 1 + initial-RMCM-application))) ;adjust the experience according to the initial rmcm application derived from the survey
      ;show sum my-materials-applied / length my-materials-applied
      if rmcm-experience >= 1 [set rmcm-experience 1]] ;delimite to > 1
    
    if Image-usage-sensitivity = true [set project-recommendation-image delimited-random-normal RMCM-image 0.17] ; adjust image parameter
    
  ] 
  
end


to update-engineer-properties
  
  ask engineers [   ;update design-specification-experience according to the materials applied in the last years (agents-experience-time)
    let my-materials-applied [materials-applied] of projects with [my-engineer = myself]   ;list the materials applied in my projects
    if length my-materials-applied > 0 [   ;update experience only if any projects done
      set design-specification-experience (design-specification-experience * ((1 + (1 / DesignSpecification-RMCMExperience) * design-specification-experience-weight * 
        (sum my-materials-applied / length my-materials-applied)) / ( 1 + initial-RMCM-application)))   ;adjust the experience according to the initial rmcm application derived from the survey
      ;show sum my-materials-applied / length my-materials-applied
      if design-specification-experience >= 1 [set design-specification-experience 1]] ;delimite to > 1
  ]
  
end


to update-contractor-properties
  
  ask contractors [   ;update tender-submission-experience according to the materials applied in the last years (agents-experience-time)
    let my-materials-applied [materials-applied] of projects with [my-contractor = myself]    ;list the materials applied in my projects
    if length my-materials-applied > 0 [    ;update experience only if any projects done
      set tender-submission-experience (tender-submission-experience * ((1 + (1 / TenderSubmission-RMCMExperience)  * tender-submission-experience-weight * 
        (sum my-materials-applied / length my-materials-applied)) / ( 1 + initial-RMCM-application)))  ;adjust the experience according to the initial rmcm application derived from the survey 
      ;show sum my-materials-applied / length my-materials-applied
      if tender-submission-experience >= 1 [set tender-submission-experience 1] ;delimite to > 1
    ]     
  ]
  
end
@#$#@#$#@
GRAPHICS-WINDOW
1232
18
2142
949
-1
-1
3.0
1
5
1
1
1
0
0
0
1
0
299
0
299
0
0
1
ticks
30.0

BUTTON
13
10
79
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
88
10
151
43
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
160
10
223
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
13
109
223
142
initial-RMCM-application
initial-RMCM-application
0
1
0.08
0.01
1
NIL
HORIZONTAL

INPUTBOX
119
45
223
105
simulation-end-year
2050
1
0
Number

SLIDER
376
534
731
567
ProjectRecommendation-RMCMExpectedPrices
ProjectRecommendation-RMCMExpectedPrices
0
1
0.4
0.05
1
NIL
HORIZONTAL

SLIDER
373
711
728
744
TenderSubmission-RMCMEconomicAspects
TenderSubmission-RMCMEconomicAspects
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
11
425
365
458
PrivateProjectConfirmation-RMCMExpectedPrices
PrivateProjectConfirmation-RMCMExpectedPrices
0
1
0.45
0.05
1
NIL
HORIZONTAL

TEXTBOX
17
179
571
199
Construction stakeholders' personal decision parameters
12
14.0
1

MONITOR
740
173
945
218
average rmcm fraction applied
global-fraction-rmcm-applied
5
1
11

BUTTON
230
10
363
44
run reference experiment
experiment
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
954
174
1086
219
total number of projects
total-num-projects
17
1
11

PLOT
739
18
944
168
current-fraction-rmcm-applied
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot current-fraction-rmcm-applied"

SLIDER
13
213
366
246
private-AA-specification-availability
private-AA-specification-availability
0
1
0.57
0.01
1
NIL
HORIZONTAL

SLIDER
13
248
366
281
commercial-AA-specification-availability
commercial-AA-specification-availability
0
1
0.42
0.01
1
NIL
HORIZONTAL

SLIDER
12
283
366
316
public-AA-specification-availability
public-AA-specification-availability
0
1
0.4
0.01
1
NIL
HORIZONTAL

TEXTBOX
378
654
719
682
Mean initial contractors' decision parameter
11
0.0
1

SLIDER
375
282
729
315
engineers-design-specification-probability
engineers-design-specification-probability
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
376
498
731
531
architects-recommendation-probability
architects-recommendation-probability
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
373
675
727
708
contractors-tender-probability
contractors-tender-probability
0
1
0.1
0.1
1
NIL
HORIZONTAL

TEXTBOX
17
198
360
216
Mean initial awarding authorities' decision parameters
11
0.0
1

SLIDER
12
318
366
351
SustainableConstructionSpecification-SocialAspects
SustainableConstructionSpecification-SocialAspects
0
1
0.75
0.05
1
NIL
HORIZONTAL

SLIDER
11
354
366
387
SustainableConstructionSpecification-EconomicAspects
SustainableConstructionSpecification-EconomicAspects
0
1
0.75
0.05
1
NIL
HORIZONTAL

SLIDER
11
388
366
421
SustainableConstructionSpecification-EcologicalAspects
SustainableConstructionSpecification-EcologicalAspects
0
1
0.75
0.05
1
NIL
HORIZONTAL

TEXTBOX
379
229
725
247
Mean initial engineers' decision parameters
11
0.0
1

SLIDER
375
319
729
352
DesignSpecification-RMCMExpectedPrices
DesignSpecification-RMCMExpectedPrices
0
1
0.4
0.05
1
NIL
HORIZONTAL

SLIDER
375
355
730
388
DesignSpecification-RMCMExperience
DesignSpecification-RMCMExperience
0
1
0.4
0.05
1
NIL
HORIZONTAL

SLIDER
375
390
730
423
DesignSpecification-RMCMNorm
DesignSpecification-RMCMNorm
0
1
0.45
0.05
1
NIL
HORIZONTAL

TEXTBOX
380
446
718
474
Mean initial architects' decision parameters
11
0.0
1

SLIDER
376
570
731
603
ProjectRecommendation-RMCMImage
ProjectRecommendation-RMCMImage
0
1
0.45
0.05
1
NIL
HORIZONTAL

SLIDER
376
606
731
639
ProjectRecommendation-RMCMAesthetics
ProjectRecommendation-RMCMAesthetics
0
1
0.35
0.05
1
NIL
HORIZONTAL

SLIDER
11
461
365
494
PrivateProjectConfirmation-RMCMTechnicalAspects
PrivateProjectConfirmation-RMCMTechnicalAspects
0
1
0.45
0.05
1
NIL
HORIZONTAL

SLIDER
11
497
365
530
PrivateProjectConfirmation-RMCMEcologicalAspects
PrivateProjectConfirmation-RMCMEcologicalAspects
0
1
0.55
0.05
1
NIL
HORIZONTAL

SLIDER
11
534
365
567
CommercialProjectConfirmation-RMCMEconomicAspects
CommercialProjectConfirmation-RMCMEconomicAspects
0
1
0.45
0.05
1
NIL
HORIZONTAL

SLIDER
11
570
366
603
CommercialProjectConfirmation-RMCMTechnicalAspects
CommercialProjectConfirmation-RMCMTechnicalAspects
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
11
606
365
639
CommercialProjectConfirmation-RMCMEcologicalAspects
CommercialProjectConfirmation-RMCMEcologicalAspects
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
373
748
728
781
TenderSubmission-RMCMExperience
TenderSubmission-RMCMExperience
0
1
0.45
0.05
1
NIL
HORIZONTAL

SLIDER
373
785
728
818
TenderSubmission-RMCMTechnicalAspects
TenderSubmission-RMCMTechnicalAspects
0
1
0.4
0.05
1
NIL
HORIZONTAL

SLIDER
376
127
724
160
Percental-RCtoCC-price-difference
Percental-RCtoCC-price-difference
-0.5
0.5
0
0.01
1
NIL
HORIZONTAL

SLIDER
12
748
365
781
PrivatTenderSelection-RMCMEcologicalAspects
PrivatTenderSelection-RMCMEcologicalAspects
0
1
0.6
0.05
1
NIL
HORIZONTAL

SLIDER
11
642
365
675
PublicProjectConfirmation-RMCMExpectedPrices
PublicProjectConfirmation-RMCMExpectedPrices
0
1
0.4
0.05
1
NIL
HORIZONTAL

SLIDER
11
677
365
710
PublicProjectConfirmation-RMCMPolicy
PublicProjectConfirmation-RMCMPolicy
0
1
0.55
0.05
1
NIL
HORIZONTAL

SLIDER
11
713
365
746
PublicProjectConfirmation-RMCMImage
PublicProjectConfirmation-RMCMImage
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
12
784
365
817
CommercialTenderSelection-RMCMMarketability
CommercialTenderSelection-RMCMMarketability
0
1
0.4
0.05
1
NIL
HORIZONTAL

PLOT
953
18
1221
169
RMCM experience
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"engineers" 1.0 0 -955883 true "" "plot mean [design-specification-experience] of engineers"
"contractors" 1.0 0 -13345367 true "" "plot mean [tender-submission-experience] of contractors"
"architects" 1.0 0 -1184463 true "" "plot mean [rmcm-experience] of architects"

PLOT
740
823
1221
1102
fraction of RMCM project decisions
NIL
NIL
2010.0
2020.0
0.0
0.5
true
true
"" ""
PENS
"AA project spec" 1.0 0 -2674135 true "" "plotxy simulation-time \n(count projects with [project-specification = 1\n and construction-year = simulation-time]) /\n(1 + count projects with [construction-year = simulation-time])"
"Eng design spec" 1.0 0 -955883 true "" "plotxy simulation-time \n(count projects with [design-specification = 1\n and  construction-year = simulation-time]) /\n (1 + count projects with [construction-year = simulation-time])"
"Arch rec" 1.0 0 -1184463 true "" "plotxy simulation-time \n(count projects with [project-recommendation = 1 \nand construction-year = simulation-time]) /\n (1 + count projects with [construction-year = simulation-time])"
"AA project conf" 1.0 0 -13840069 true "" "plotxy simulation-time \n(count projects with [project-confirmation = 1 \nand construction-year = simulation-time]) /\n(1 + count projects with [construction-year = simulation-time])"
"Contr tender" 1.0 0 -13345367 true "" "plotxy simulation-time \n(count projects with [rmcm-tender = 1 \nand construction-year = simulation-time]) /\n(1 + count projects with [construction-year = simulation-time])"
"AA tender selection" 1.0 0 -16777216 true "" "plotxy simulation-time \n(count projects with [tender-selection = 1\nand  construction-year = simulation-time]) /\n(1 + count projects with [construction-year = simulation-time])"

MONITOR
230
47
364
92
NIL
simulation-time
0
1
11

SLIDER
376
165
724
198
agents-experience-time
agents-experience-time
0
10
5
1
1
NIL
HORIZONTAL

INPUTBOX
13
45
113
105
simulation-start-year
2010
1
0
Number

MONITOR
1095
174
1221
219
num projects in system
count projects
0
1
11

SWITCH
376
11
541
44
AA-price-sensitivity
AA-price-sensitivity
0
1
-1000

SWITCH
376
48
541
81
Expert-price-sensitivity
Expert-price-sensitivity
0
1
-1000

SWITCH
377
85
541
118
Image-usage-sensitivity
Image-usage-sensitivity
0
1
-1000

PLOT
740
274
1222
532
aggregate volumes [t]
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"concrete rubble supply" 1.0 0 -2674135 true "" "plot annual-concrete-rubble-supply"
"mixed rubble supply" 1.0 0 -13345367 true "" "plot annual-mixed-rubble-supply"
"concrete rubble demand" 1.0 0 -955883 true "" "plot concrete-rubble-demand"
"mixed rubble demand" 1.0 0 -11221820 true "" "plot mixed-rubble-demand"

MONITOR
740
222
946
267
Fraction of projects with rmcm 
rmcm-project-fraction
5
1
11

SLIDER
556
48
721
81
RC-M-fraction
RC-M-fraction
0
1
0.1
0.05
1
NIL
HORIZONTAL

SLIDER
556
10
720
43
RA-substitution-fraction
RA-substitution-fraction
0
1
0.25
0.05
1
NIL
HORIZONTAL

SLIDER
229
109
364
142
investment-scenario
investment-scenario
-1
1
1
1
1
NIL
HORIZONTAL

SLIDER
556
85
720
118
recycling-efficiency
recycling-efficiency
0
1
0.95
0.05
1
NIL
HORIZONTAL

PLOT
740
535
1221
819
demand concrete volumes [m3]
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"RC-C volume" 1.0 0 -955883 true "" "plot amount-of-current-rmcm-applied * (1 - RC-M-fraction) / 2.4"
"RC-M volume" 1.0 0 -11221820 true "" "plot amount-of-current-rmcm-applied * RC-M-fraction / 2.4"
"CC volume" 1.0 0 -7500403 true "" "plot amount-of-current-cm-applied / 2.4"

SLIDER
375
247
728
280
Engineers-project-spec-sensitivity
Engineers-project-spec-sensitivity
0
1
1
0.01
1
NIL
HORIZONTAL

SLIDER
377
462
730
495
Architects-spec-sensitivity
Architects-spec-sensitivity
0
1
1
0.01
1
NIL
HORIZONTAL

@#$#@#$#@
#CONSTRUCTION STAKEHOLDERS MODEL (BUILDINGS)

The model is based on a Swiss case study (Please see Knoeri et.al. (2011a,b) for details). A detailed description and results are published in:

Knoeri, C., Nikolić, I., Althaus, H. J., & Binder, C. (2012). Enhancing recycling of construction materials; the role of empirically based decision parameters. Submitted to JASSS the Journal of Artificial Societies and Social Simulation.

References: 
 
Knoeri, C., Binder, C. R., & Althaus, H. J. (2011a). An agent operationalization approach for context specific agent-based modeling. JASSS the Journal of Artificial Societies and Social Simulation, 14(2).
 
Knoeri, C., Binder, C. R., & Althaus, H. J. (2011b). Decisions on recycling: Construction stakeholders’ decisions regarding recycled mineral construction materials. Resources, Conservation and Recycling, 55(11), 1039-1050.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="DemandVariability" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <enumeratedValueSet variable="PrivateProjectConfirmation-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialProjectConfirmation-RMCMEconomicAspects">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialTenderSelection-RMCMMarketability">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SustainableConstructionSpecification-SocialAspects">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="engineers-design-specification-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ProjectRecommendation-RMCMAesthetics">
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PrivateProjectConfirmation-RMCMEcologicalAspects">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PrivatTenderSelection-RMCMEcologicalAspects">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Expert-price-sensitivity">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-end-year">
      <value value="2020"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SustainableConstructionSpecification-EconomicAspects">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PublicProjectConfirmation-RMCMImage">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-AA-specification-availability">
      <value value="0.42"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PrivateProjectConfirmation-RMCMTechnicalAspects">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="simulation-start-year">
      <value value="2010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SustainableConstructionSpecification-EcologicalAspects">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PublicProjectConfirmation-RMCMExpectedPrices">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public-AA-specification-availability">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="TenderSubmission-RMCMEconomicAspects">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Image-usage-sensitivity">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialProjectConfirmation-RMCMEcologicalAspects">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="TenderSubmission-RMCMExperience">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AA-price-sensitivity">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="agents-experience-time">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentual-RCtoCC-price-difference">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ProjectRecommendation-RMCMExpectedPrices">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExpectedPrices">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialProjectConfirmation-RMCMTechnicalAspects">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contractors-tender-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment-scenario">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PublicProjectConfirmation-RMCMPolicy">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RC-M-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recycling-efficiency">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="TenderSubmission-RMCMTechnicalAspects">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExperience">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMNorm">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ProjectRecommendation-RMCMImage">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private-AA-specification-availability">
      <value value="0.57"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="architects-recommendation-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-RMCM-application">
      <value value="0.08"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ExpertSpecificationSensitivity" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <steppedValueSet variable="Architects-spec-sensitivity" first="0" step="0.2" last="1"/>
    <steppedValueSet variable="Engineers-project-spec-sensitivity" first="0" step="0.2" last="1"/>
  </experiment>
  <experiment name="Scenario2Public" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.25"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public-AA-specification-availability">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMNorm">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario3Price" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="CommercialTenderSelection-RMCMMarketability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentual-RCtoCC-price-difference">
      <value value="-0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.25"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PublicProjectConfirmation-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ProjectRecommendation-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="TenderSubmission-RMCMEconomicAspects">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialProjectConfirmation-RMCMEconomicAspects">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SustainableConstructionSpecification-EconomicAspects">
      <value value="0.85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PrivateProjectConfirmation-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario4InformationPrice" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="CommercialTenderSelection-RMCMMarketability">
      <value value="0.44"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentual-RCtoCC-price-difference">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.25"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PublicProjectConfirmation-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ProjectRecommendation-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="TenderSubmission-RMCMEconomicAspects">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialProjectConfirmation-RMCMEconomicAspects">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExperience">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Architects-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SustainableConstructionSpecification-EconomicAspects">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Engineers-project-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PrivateProjectConfirmation-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario5Combined" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="CommercialTenderSelection-RMCMMarketability">
      <value value="0.44"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentual-RCtoCC-price-difference">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.25"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PublicProjectConfirmation-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ProjectRecommendation-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="TenderSubmission-RMCMEconomicAspects">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialProjectConfirmation-RMCMEconomicAspects">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExperience">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Architects-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SustainableConstructionSpecification-EconomicAspects">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Engineers-project-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PrivateProjectConfirmation-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMNorm">
      <value value="0.55"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario1Information" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.25"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Architects-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Engineers-project-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario1InformationMFA" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="private-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Architects-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-AA-specification-availability">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RC-M-fraction">
      <value value="0.1"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Engineers-project-spec-sensitivity">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario2PublicMFA" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="public-AA-specification-availability">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMNorm">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RC-M-Fraction">
      <value value="0.1"/>
      <value value="0.7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario3PriceMFA" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <metric>concrete-rubble-demand</metric>
    <metric>mixed-rubble-demand</metric>
    <metric>annual-concrete-rubble-supply</metric>
    <metric>annual-mixed-rubble-supply</metric>
    <enumeratedValueSet variable="CommercialTenderSelection-RMCMMarketability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Percentual-RCtoCC-price-difference">
      <value value="-0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PublicProjectConfirmation-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ProjectRecommendation-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="TenderSubmission-RMCMEconomicAspects">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="DesignSpecification-RMCMExpectedPrices">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommercialProjectConfirmation-RMCMEconomicAspects">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SustainableConstructionSpecification-EconomicAspects">
      <value value="0.85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PrivateProjectConfirmation-RMCMExpectedPrices">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="RC-M-fraction">
      <value value="0.1"/>
      <value value="0.7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="RAFractionExperiment" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>global-fraction-rmcm-applied</metric>
    <enumeratedValueSet variable="RA-substitution-fraction">
      <value value="0.25"/>
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
